# Summary

> Description of the issue.

# Environment

- __OS__: Windows/Mac/Linux + the version of your OS.
- __Python Version__: Run `python --version` to make sure.
- __Zrb Version__: Run `zrb version` to make sure.

# Action

- I set the following environment variables
- I run the following command
- etc.


# Expected Result

> Description of your expectation.

# Actual Result

> Description of actual result. Put output/screenshots.